@@ -7,3 +7,7 @@ DJANGO_DB_LOCK_APP_LABEL = getattr(settings, "DJANGO_DB_LOCK_APP_LABEL", "django
 DJANGO_DB_LOCK_API_SERVER = getattr(settings, "DJANGO_DB_LOCK_API_SERVER", None)
 DJANGO_DB_LOCK_ACQUIRE_LOCK_PATH = getattr(settings, "DJANGO_DB_LOCK_ACQUIRE_LOCK_PATH", "acquireLock")
 DJANGO_DB_LOCK_RELEASE_LOCK_PATH = getattr(settings, "DJANGO_DB_LOCK_RELEASE_LOCK_PATH", "releaseLock")
+
+DJANGO_DB_LOCK_REDIS_CACHE_NAME = getattr(settings, "DJANGO_DB_LOCK_REDIS_CACHE_NAME", "default")
+DJANGO_DB_LOCK_USA_REDIS_CACHE = getattr(settings, "DJANGO_DB_LOCK_USA_REDIS_CACHE", True)
+DJANGO_DB_LOCK_REDIS_CACHE_PREFIX = getattr(settings, "DJANGO_DB_LOCK_REDIS_CACHE_PREFIX", "django-db-lock:locks")
